### twitographer -- a parallelized web crawler to traverse the twitter graph
--------

**this is a tiny script that uses [miyakogi's python port](https://github.com/miyakogi/pyppeteer) of [google's puppeteer headless browser](https://github.com/GoogleChrome/puppeteer) to traverse the twitter graph, logging the friends of each account.**

i wrote this for a big data analysis project to infer twitter communities from aggregated social relationships.

add your twitter username and password `creds.py` before running
